@@ -243,7 +243,7 @@ def check_int_column(data, int_col):
     nrows = data.shape[0]
     # Remove any non-digit characters, convert to numeric, setting non-numeric to NaN
     data[int_col] = pd.to_numeric(
-        data[int_col].astype(str).str.replace(r'[^\d]', '', regex=True),
+        data[int_col].astype(str).str.replace(r'(\d+)', '', regex=True),
         errors='coerce'
     )
     # Convert to Int64 which handles NaN values, using round() first to handle floats
